import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class StreamProviderView<T> extends ConsumerWidget {
  final dynamic initialData;
  final AutoDisposeStreamProvider<T> streamProvider;
  final Function(BuildContext, T?) builder;
  final Widget? loader;

  StreamProviderView({
    this.initialData,
    required this.streamProvider,
    required this.builder,
    this.loader
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    return ref.watch(streamProvider).when(data: (snapshot) {
      return builder(context, snapshot);
    }, error: (err, _) {
      return Center(child: Text("$err"));
    }, loading: () {
      return loader ?? Center(child: CircularProgressIndicator());
    });
  }
}